History
=======

development
-----------

- Add add-on functionality!

  - Support todo.sh_'s add-ons_

- Add colorama support for users using the script in ``cmd.exe`` on 
  Windows
- Add tests for ``get_config()``
- Add @usage decorate for actions
- Add sample_addons directory with Matt Stave's suggestions
- PEP257 (Docstring) compliance
- Help documentation automattically generated
- Fix rare occurrence where script whips out todo.txt file

.. _todo.sh: https://github.com/ginatrapani/todo.txt-cli
.. _add-ons:
    https://github.com/ginatrapani/todo.txt-cli/wiki/Todo.sh-Add-on-Directory
